severity = 1
color = 1
verbose = 8

# Configure these policies
[InputOutput::RequireCheckedSyscalls]
exclude_functions = print

# Do not load these policies
[-CodeLayout::ProhibitParensWithBuiltins]
[-CodeLayout::RequireTidyCode]
[-ControlStructures::ProhibitCStyleForLoops]
[-ControlStructures::ProhibitPostfixControls]
[-ControlStructures::ProhibitUnlessBlocks]
[-Subroutines::ProhibitBuiltinHomonyms]
[-ValuesAndExpressions::ProhibitNoisyQuotes]
[-ValuesAndExpressions::RequireInterpolationOfMetachars]
[-Variables::ProhibitPunctuationVars]
